/**
 * @file label_trash.js
 * 
 * Takes parameters set on the configuration page and invokes floatlabel.js
 */
(function ($) {
  Drupal.behaviors.label_trash_attach = {

    attach: function(context, settings) {

      $(settings.label_trash, context).each(function() {

        // settings is an array of params indexed by CSS input field selector
        for (var selector in this) {
          var inputs = $(selector);

          inputs.each(function() {
            var placeholder = $(this).attr('placeholder');
            // If the input element does not already have a placeholder,
            // create one based on its neighbouring label element
            if (!placeholder) {
              var label = $(this).prev('label');
              placeholder = label.html();
              if (placeholder) {
                $(this).attr('data-label', placeholder);
                // Deal with placeholders containing HTML, like:
                // 'Title <span class="form-required" title="Field is required.">*</span>'
                var split = placeholder.indexOf('<');
                var placeholder_escaped = split < 0 ? placeholder : placeholder.substring(0, split) + $(placeholder.substring(split)).text();
                $(this).attr('placeholder', placeholder_escaped);
                label.remove(); // label.hide();
              }
            }
          });
          var params = this[selector];
          if (params['label-style']) {

            inputs.floatlabel({
              labelStartTop: params['floatlabel-offset-top-start'],
              labelEndTop: params['floatlabel-offset-top-end'],
              labelClass: params['data-class'],
              transitionDuration: params['transition-duration'],
              transitionEasing: params['transition-easing'],
            });
          }
        }
      });
    }
  }
}) (jQuery);
